//importing necessary modules from D3 library
import { select, json, geoPath, geoEquirectangular } from 'd3';
//importing feature method from TopoJSON which will create the GeoJSON objects
import { feature } from 'topojson';

//Selecting the SVG element in the DOM and storing it in a constant named 'svg'
//accessing DOM element using select()
const svg = select('svg');

//Creating constants for the geo-projection and path generator using the 'geoEquirectangular' function to view the world map
const projection = geoEquirectangular();
const pathGenerator = geoPath().projection(projection);

//adding path element to the created SVG
//defining the attribute class as 'earth'
//considering the pathGenerator type as Sphere
svg.append('path')
    .attr('class', 'earth')
    .attr('d', pathGenerator({type: 'Sphere'}));

//Loading a .JSON file with world map data using the 'json' method
json('https://cdn.jsdelivr.net/npm/world-atlas@2/countries-110m.json')
  .then(data => {
//Using the feature method to create GeoJSON objects for each country
    const countries = feature(data, data.objects.countries);
//Selecting path elements and binding the GeoJSON data to them
    svg.selectAll('path').data(countries.features)
//enter() creates the initial join of data to elements
//defining a class 'countries'
//Use pathGenerator to generate path for each countries
      .enter().append('path')
        .attr('class', 'countries')
        .attr('d', pathGenerator);
  });